# Generated by roxygen2: do not edit by hand

S3method(anova,glmb)
S3method(case.names,glmb)
S3method(check_prior,glmb)
S3method(confint,glmb)
S3method(cooks.distance,glmb)
S3method(describe_prior,glmb)
S3method(deviance,rglmb)
S3method(dfbetas,glmb)
S3method(dummy.coef,glmb)
S3method(extractAIC,glmb)
S3method(extractAIC,rglmb)
S3method(find_algorithm,glmb)
S3method(find_parameters,glmb)
S3method(formula,summary.rglmb)
S3method(get_data,glmb)
S3method(get_parameters,glmb)
S3method(get_priors,glmb)
S3method(influence,glmb)
S3method(logLik,glmb)
S3method(model_info,glmb)
S3method(pfamily,default)
S3method(plot,glmb)
S3method(predict,glmb)
S3method(print,PriorSetup)
S3method(print,directional_tail)
S3method(print,dummy_coef.glmb)
S3method(print,glmb)
S3method(print,glmbfamfunc)
S3method(print,lmb)
S3method(print,mlmb)
S3method(print,pfamily)
S3method(print,rGamma_reg)
S3method(print,rglmb)
S3method(print,rlmb)
S3method(print,simfunction)
S3method(print,summary.glmb)
S3method(print,summary.mlmb)
S3method(print,summary.rGamma_reg)
S3method(print,summary.rglmb)
S3method(residuals,glmb)
S3method(residuals,lmb)
S3method(residuals,rglmb)
S3method(rstandard,glmb)
S3method(rstudent,glmb)
S3method(simfunction,default)
S3method(simulate,glmb)
S3method(simulate_prior,glmb)
S3method(summary,glmb)
S3method(summary,mlmb)
S3method(summary,rGamma_reg)
S3method(summary,rglmb)
S3method(variable.names,glmb)
S3method(vcov,glmb)
export(EnvelopeBuild)
export(EnvelopeCentering)
export(EnvelopeDispersionBuild)
export(EnvelopeEval)
export(EnvelopeOpt)
export(EnvelopeOrchestrator)
export(EnvelopeSetGrid)
export(EnvelopeSetLogP)
export(EnvelopeSize)
export(EnvelopeSort)
export(Prior_Check)
export(Prior_Setup)
export(check_prior)
export(compute_gaussian_prior)
export(dBeta)
export(dGamma)
export(dIndependent_Normal_Gamma)
export(dNormal)
export(dNormal_Gamma)
export(describe_prior)
export(diagnose_glmbayes)
export(directional_tail)
export(extractDIC)
export(find_algorithm)
export(find_parameters)
export(get_data)
export(get_opencl_core_count)
export(get_parameters)
export(get_priors)
export(glmb)
export(glmb.covratio)
export(glmb.dffits)
export(glmb.influence.measures)
export(glmb.wfit)
export(glmb_Standardize_Model)
export(glmbfamfunc)
export(has_opencl)
export(lmb)
export(model_info)
export(multi_prior_setup)
export(pfamily)
export(pinvgamma_ct)
export(pnorm_ct)
export(qinvgamma_ct)
export(rBeta_prior)
export(rBeta_reg)
export(rGamma_Conjugate_prior)
export(rGamma_Conjugate_reg)
export(rGamma_prior)
export(rGamma_reg)
export(rIndepNormalGammaReg_std)
export(rIndependent_Normal_Gamma_prior)
export(rNormalGLM_std)
export(rNormalGamma_reg)
export(rNormal_Gamma_prior)
export(rNormal_prior)
export(rNormal_reg)
export(rNormal_reg.wfit)
export(rgamma_ct)
export(rglmb)
export(rindepNormalGamma_reg)
export(rinvgamma_ct)
export(rlmb)
export(rnorm_ct)
export(simfunction)
export(simulate_prior)
import(Rcpp)
import(nmathopencl)
import(opencltools)
import(stats)
importFrom(MASS,mvrnorm)
importFrom(Rcpp,evalCpp)
importFrom(RcppParallel,RcppParallelLibs)
importFrom(Rdpack,reprompt)
importFrom(bayestestR,check_prior)
importFrom(bayestestR,describe_prior)
importFrom(bayestestR,simulate_prior)
importFrom(insight,find_algorithm)
importFrom(insight,find_parameters)
importFrom(insight,get_data)
importFrom(insight,get_parameters)
importFrom(insight,get_priors)
importFrom(insight,model_info)
importFrom(utils,head)
useDynLib(glmbayes, .registration = TRUE)
